from __future__ import absolute_import

class AnsibleAdapterBase(object):
    def __init__(self, vault_password):
        self.vault_password = vault_password
        self.init()

    def init(self):
        pass

    def is_encrypted_vault(self, filename):
        raise NotImplementedError()

    def encrypt_vault(self, filename):
        raise NotImplementedError()

    def decrypt_vault(self, filename):
        raise NotImplementedError()

    def vault_plaintext(self, filename):
        raise NotImplementedError()



from __future__ import absolute_import

from peewee import SqliteDatabase, Model, CharField, TextField, IntegerField


class BaseModel(Model):
    pass

class Vault(BaseModel):
    filename = CharField(unique=True, primary_key=True)
    contents = TextField(null=True)
    mtime = IntegerField(null=True)


def init_models(db):
    models = [
        Vault
    ]

    database = SqliteDatabase(db)

    # wire models with database
    for model in models:
        model._meta.database = database

    database.create_tables(models, safe=True)
